##  Suggested SAP Solutions
For level 3 business capabilities from the catalog, the reference catalog suggests appropriate SAP solutions that could best support those capabilities. The applications are grouped into options, each referring to the Solution Capabilities from the SAP Reference Solution Architecture. Each option includes the name of the corresponding Solution Capability in the subheading for easy reference.
To view suggested SAP solutions in the reference catalog, do the following:
  1. On the navigation bar, click More > Reference Catalog > Business Capability Linking.
  2. In the reference catalog, click Preview options to view suggested SAP solutions. If you're on the Unlinked tab, select a catalog item first to preview suggested solutions.
![Previewing Suggested SAP Solutions from the Reference Business Architecture Page](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2746b6887a4410148926cbf95d70b522_LowRes.png)
Previewing Suggested SAP Solutions in the Reference Catalog
  3. In the preview overlay, select an SAP S/4HANA deployment option to filter the suggested solutions based on the chosen option. The following options are available:
     * Cloud: SAP S/4HANA Public Cloud
     * Hybrid: SAP S/4HANA Private Cloud or On-Premise


Additionally, you can view suggested solutions for a specific business capability by opening the linked reference catalog item from the right-side pane of a specific fact sheet.
Furthermore, if you use SAP LeanIX Architecture and Road Map Planning, suggested SAP solutions also appear on the Transformations tab of the linked business capability fact sheets. You can choose a suggested solution and automatically prepare transformations to roll out or introduce the relevant applications. To learn more, see [Planning Transformations for SAP Solutions](https://help.sap.com/docs/leanix/ea/planning-transformations-for-sap-solutions?locale=en-US&state=PRODUCTION&version=CLOUD "Link business capabilities to reference catalog items to view suggested SAP solutions and automatically plan transformations with SAP LeanIX Architecture and Road Map Planning.").
